@@ -10,7 +10,7 @@ use super::*;
 pub const SVG_HEADER: &str = r##"<svg class="poloto" width="800" height="500" viewBox="0 0 800 500" xmlns="http://www.w3.org/2000/svg">"##;
 
 ///
-/// The default svg dimentions for simple theme.
+/// The default svg dimensions for simple theme.
 ///
 pub const DIM: [f64; 2] = [800.0, 500.0];
 
@@ -130,7 +130,7 @@ pub trait SimpleTheme {
     fn simple_theme_dark<T: fmt::Write>(self, a: T) -> std::fmt::Result;
 }
 
-impl<P: build::PlotIterator<Item = (B::X, B::Y)>, K: Borrow<Canvas>, B: BaseFmt> SimpleTheme
+impl<P: build::PlotIterator<Item = (B::X, B::Y)>, K: Renderable, B: BaseFmt> SimpleTheme
     for Plotter<P, K, B>
 {
     fn simple_theme<T: fmt::Write>(self, mut a: T) -> std::fmt::Result {
